.. currentmodule:: sardana.spock.test.test_parameter
.. _test_parameter:

:mod:`~sardana.spock.test.test_parameter`
=========================================

.. automodule:: sardana.spock.test.test_parameter

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`ParamTestCase`


ParamTestCase
-------------

.. inheritance-diagram:: ParamTestCase
    :parts: 1

.. autoclass:: ParamTestCase
    :members:
    :undoc-members:
